"""
Mock of cPyparsing as Python pyparsing for the sake of timing comparison.
"""

print("pyparsing -> cPyparsing mock loaded")

from cPyparsing import *
from cPyparsing import __version__, _trim_arity
from cPyparsing import pyparsing_test



"""
Mock of Python pyparsing as cPyparsing for the sake of timing comparison.
"""

print("cPyparsing -> pyparsing mock loaded")

from pyparsing import *
from pyparsing import __version__, _trim_arity
from pyparsing import pyparsing_test
